@@ -9,25 +9,27 @@ class HttpApiConfig(TypedDict):
     secret: str;
 
 class HttpApi:
-    def __init__(self, config: HttpApiConfig):
-        self.config = config
+    def __init__(self, agentlabs_url: str, project_id: str, secret: str) -> None:
+        self.agentlabs_url = agentlabs_url
+        self.project_id = project_id
+        self.secret = secret
         self.client = requests.Session()
         self.client.params = {
-            "projectId": config["project_id"],
+            "projectId": self.project_id
         }
         self.client.headers.update({
-            "x-agentlabs-sdk-secret": config["secret"],
-            "x-agentlabs-project-id": config["project_id"],
+            "x-agentlabs-sdk-secret": self.secret,
+            "x-agentlabs-project-id": self.project_id,
         })
 
     def _make_url(self, path: str):
-        return self.config["agentlabs_url"] + path
+        return self.agentlabs_url + path
 
     def create_message_attachment(self, agent_id: str, message_id: str, attachment: Attachment):
         url = self._make_url("/agent-attachments/createMessageAttachmentSync")
         res = requests.post(url, params={
             message_id: message_id,
-            "projectId": self.config["project_id"],
+            "projectId": self.project_id,
             "agentId": agent_id
         }, files={
             "file": attachment.buffer
